@@ -50,7 +50,6 @@
 #include <libgnomevfs/gnome-vfs-utils.h>
 #include <libgnomevfs/gnome-vfs-mime-info.h>
 #include <glib/gi18n-lib.h>
-#include <locale.h>
 #include <openbabel/mol.h>
 #include <openbabel/obconversion.h>
 #ifdef HAVE_FSTREAM
@@ -58,6 +57,7 @@
 #else
 #	include <fstream.h>
 #endif
+#include <clocale>
 
 // following code is needed to get file extensions, it as been essentially copied from gnome-vfs
 static map<string, list<string> > globs;
@@ -219,7 +219,6 @@ static Object* CreateFragment ()
 	return new gcpFragment ();
 }
 
-list<gcpApplication*> Apps;
 bool	gcpApplication::m_bInit = false;
 bool	gcpApplication::m_Have_Ghemical = false;
 bool	gcpApplication::m_Have_InChI = false;
@@ -232,7 +231,6 @@ static void on_config_changed (GConfClient *client, guint cnxn_id, GConfEntry *e
 gcpApplication::gcpApplication ():
 	Application ("GChemPaint", DATADIR, PACKAGE, "gchempaint")
 {
-	Apps.push_back(this);
 	m_CurZ = 6;
 	m_pActiveDoc = NULL;
 	m_pActiveTool = NULL;
@@ -358,7 +356,6 @@ gcpApplication::~gcpApplication()
 	for (; tool!= endtool; tool++)
 		delete (*tool).second;
 	Tools.clear ();
-	Apps.remove (this);
 	if (XmlDoc)
 		xmlFreeDoc (XmlDoc);
 	m_SupportedMimeTypes.clear ();
@@ -447,8 +444,16 @@ bool gcpApplication::FileProcess (const gchar* filename, const gchar* mime_type,
 			file_type = SVG;
 		else if (!strcmp (mime_type, "image/x-eps"))
 			file_type = EPS;
-		else if ((pixbuf_type = GetPixbufTypeName (filename2, mime_type)))
+		else if ((pixbuf_type = GetPixbufTypeName (filename2, mime_type))) {
 			file_type = PIXBUF;
+			if (!ext) {
+				filename = filename2.c_str ();
+				i = strlen (filename) - 1;
+				while ((i > 0) && (filename[i] != '.') && (filename[i] != '/')) i--;
+				if (filename[i] == '/') i = 0;
+				ext = (i > 0)? filename + i + 1: NULL;
+			}
+		}
 	}
 	if (file_type < 0 || (!bSave && (file_type > CHEMISTRY))) {
 		GtkWidget* message = gtk_message_dialog_new (window, GTK_DIALOG_MODAL, GTK_MESSAGE_ERROR, GTK_BUTTONS_OK, 
@@ -542,8 +547,8 @@ void gcpApplication::SaveWithBabel (string const &filename, const gchar *mime_ty
 	data.display_name = (char*) pDoc->GetTitle ();
 	data.description = NULL;
 	data.mime_type = (char*) mime_type;
-	data.app_name = "gchempaint";
-	data.app_exec = "gchempaint %u";
+	data.app_name = (char*) "gchempaint";
+	data.app_exec = (char*) "gchempaint %u";
 	data.groups = NULL;
 	data.is_private =  FALSE;
 	gtk_recent_manager_add_full (GetRecentManager (), filename.c_str (), &data);
@@ -643,8 +648,8 @@ void gcpApplication::OpenWithBabel (string const &filename, const gchar *mime_ty
 		data.display_name = (char*) pDoc->GetTitle ();
 		data.description = NULL;
 		data.mime_type = (char*) mime_type;
-		data.app_name = "gchempaint";
-		data.app_exec = "gchempaint %u";
+		data.app_name = (char*) "gchempaint";
+		data.app_exec = (char*) "gchempaint %u";
 		data.groups = NULL;
 		data.is_private =  FALSE;
 		gtk_recent_manager_add_full (GetRecentManager (), filename.c_str (), &data);
@@ -682,9 +687,9 @@ void gcpApplication::SaveGcp (string const &filename, gcpDocument* pDoc)
 	GtkRecentData data;
 	data.display_name = (char*) pDoc->GetTitle ();
 	data.description = NULL;
-	data.mime_type = "application/x-gchempaint";
-	data.app_name = "gchempaint";
-	data.app_exec = "gchempaint %u";
+	data.mime_type = (char*) "application/x-gchempaint";
+	data.app_name = (char*) "gchempaint";
+	data.app_exec = (char*) "gchempaint %u";
 	data.groups = NULL;
 	data.is_private =  FALSE;
 	gtk_recent_manager_add_full (GetRecentManager (), filename.c_str (), &data);
@@ -753,9 +758,9 @@ void gcpApplication::OpenGcp (string const &filename, gcpDocument* pDoc)
 		GtkRecentData data;
 		data.display_name = (char*) pDoc->GetTitle ();
 		data.description = NULL;
-		data.mime_type = "application/x-gchempaint";
-		data.app_name = "gchempaint";
-		data.app_exec = "gchempaint %u";
+		data.mime_type = (char*) "application/x-gchempaint";
+		data.app_name = (char*) "gchempaint";
+		data.app_exec = (char*) "gchempaint %u";
 		data.groups = NULL;
 		gtk_recent_manager_add_full (GetRecentManager (), filename.c_str (), &data);
 	}
