@@ -27,8 +27,8 @@
 #include "theme.h"
 #include "settings.h"
 #include <glib/gi18n-lib.h>
-#include <math.h>
 #include <sys/stat.h>
+#include <cmath>
 
 double DefaultBondLength = 140.;
 double DefaultBondAngle = 120.;
@@ -87,13 +87,13 @@ gcpTheme::gcpTheme (char const *name)
 	m_ObjectPadding = DefaultObjectPadding;
 	m_SignPadding = DefaultSignPadding;
 	m_ChargeSignSize = DefaultChargeSignSize;
-	m_FontFamily = strdup (DefaultFontFamily);
+	m_FontFamily = strdup ((DefaultFontFamily)? DefaultFontFamily: "Bitstream Vera Sans");
 	m_FontStyle = DefaultFontStyle;
 	m_FontWeight = DefaultFontWeight;
 	m_FontVariant = DefaultFontVariant;
 	m_FontStretch = DefaultFontStretch;
 	m_FontSize = DefaultFontSize;
-	m_TextFontFamily = strdup (DefaultTextFontFamily);
+	m_TextFontFamily = strdup ((DefaultTextFontFamily)? DefaultTextFontFamily: "Bitstream Vera Serif");
 	m_TextFontStyle = DefaultTextFontStyle;
 	m_TextFontWeight = DefaultTextFontWeight;
 	m_TextFontVariant = DefaultTextFontVariant;
@@ -177,6 +177,10 @@ static int set_fontsize (double val) {return (int) (val * PANGO_SCALE);}
 
 gcpThemeManager::gcpThemeManager ()
 {
+	bindtextdomain(GETTEXT_PACKAGE, LOCALEDIR);
+#ifdef ENABLE_NLS
+	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
+#endif
 	GError *error = NULL;
 	m_ConfClient = gconf_client_get_default ();
 	gconf_client_add_dir (m_ConfClient, "/apps/gchempaint/settings", GCONF_CLIENT_PRELOAD_ONELEVEL, NULL);
@@ -193,7 +197,7 @@ gcpThemeManager::gcpThemeManager ()
 	GCU_GCONF_GET (ROOTDIR"hash-width", float, DefaultHashWidth, 1.0)
 	GCU_GCONF_GET (ROOTDIR"hash-dist", float, DefaultHashDist, 2.0)
 	GCU_GCONF_GET (ROOTDIR"stereo-width", float, DefaultStereoBondWidth, 5.0)
-	GCU_GCONF_GET_N_TRANSFORM (ROOTDIR"scale", float, DefaultZoomFactor, 0.25, inv)
+	GCU_GCONF_GET_N_TRANSFORM (ROOTDIR"scale", float, DefaultZoomFactor, 4.0, inv)
 	GCU_GCONF_GET (ROOTDIR"padding", float, DefaultPadding, 2.0)
 	GCU_GCONF_GET (ROOTDIR"arrow-padding", float, DefaultArrowPadding, 16.0)
 	GCU_GCONF_GET (ROOTDIR"stoichiometry-padding", float, DefaultStoichiometryPadding, 1.)
@@ -214,7 +218,7 @@ gcpThemeManager::gcpThemeManager ()
 	GCU_GCONF_GET_N_TRANSFORM (ROOTDIR"text-font-size", float, DefaultTextFontSize, 12., set_fontsize)
 	m_NotificationId = gconf_client_notify_add (m_ConfClient, "/apps/gchempaint/settings", (GConfClientNotifyFunc) on_config_changed, this, NULL, NULL);
 	// Build default theme from settings
-	m_Themes["Default"] = new gcpTheme ("Default");
+	m_Themes["Default"] = m_Themes[_("Default")] = new gcpTheme ("Default");
 	m_Names.push_front (_("Default"));
 	// load global themes
 	string path = DATADIR;
@@ -235,10 +239,12 @@ gcpThemeManager::~gcpThemeManager ()
 	gconf_client_remove_dir (m_ConfClient, "/apps/gchempaint/settings", NULL);
 	g_object_unref (m_ConfClient);
 	// save themes if needed, then delete
-	gcpTheme *theme;
+	gcpTheme *theme, *def = NULL;
 	map <string, gcpTheme*>::iterator i, iend = m_Themes.end ();
 	for (i = m_Themes.begin (); i != iend; i++) {
 		theme = (*i).second;
+		if (!theme || (def && theme == def))
+			continue; // this theme has already been deleted
 		if (theme->modified && theme->m_ThemeType == LOCAL_THEME_TYPE) {
 			xmlDocPtr doc = xmlNewDoc((xmlChar*)"1.0");
 			xmlDocSetRootElement (doc,  xmlNewDocNode (doc, NULL, (xmlChar*) "chemistry", NULL));
@@ -263,8 +269,9 @@ gcpThemeManager::~gcpThemeManager ()
 				path += string ("/") + theme->GetName ();
 				xmlSaveFormatFile (path.c_str (), doc, true);
 			}
-		}
-		delete (*i).second;
+		} else if (theme->m_Name == "Default")
+			def = theme;
+		delete theme;
 	}
 	g_free (DefaultFontFamily);
 	g_free (DefaultTextFontFamily);
@@ -272,12 +279,12 @@ gcpThemeManager::~gcpThemeManager ()
 
 gcpTheme *gcpThemeManager::GetTheme (char const *name)
 {
-	return m_Themes[_(name)];
+	return m_Themes[name];
 }
 
 gcpTheme *gcpThemeManager::GetTheme (string &name)
 {
-	return m_Themes[_(name.c_str ())];
+	return m_Themes[name.c_str ()];
 }
 
 list <string> const &gcpThemeManager::GetThemesNames ()
@@ -291,7 +298,7 @@ void gcpThemeManager::OnConfigChanged (GConfClient *client, guint cnxn_id, GConf
 		return;	// we might want an error message?
 	if (cnxn_id != m_NotificationId)
 		return;	// we might want an error message?
-	gcpTheme *Theme = m_Themes[_("Default")];
+	gcpTheme *Theme = m_Themes["Default"];
 	if (!strcmp (gconf_entry_get_key (entry),ROOTDIR"bond-length")) {
 		DefaultBondLength = gconf_value_get_float (gconf_entry_get_value (entry));
 		Theme->m_BondLength = DefaultBondLength;
@@ -506,9 +513,15 @@ void gcpThemeManager::AddFileTheme (gcpTheme *theme, char const *label)
 
 void gcpThemeManager::RemoveFileTheme (gcpTheme *theme)
 {
-	char const *name = theme->GetName ().c_str ();
-	m_Themes.erase (name);
+	char const *name = NULL;
+	map <string, gcpTheme*>::iterator i, iend = m_Themes.end ();
+	for (i = m_Themes.begin (); i != iend; i++)
+		if ((*i).second == theme) {
+			name = (*i).first.c_str ();
+			break;
+		}
 	m_Names.remove (name);
+	m_Themes.erase (name);
 }
 
 void gcpThemeManager::ChangeThemeName (gcpTheme *theme, char const *name)
@@ -592,13 +605,13 @@ bool gcpTheme::Save (xmlDocPtr xml)
 	buf = NULL;
 	switch (m_FontStyle) {
 	case PANGO_STYLE_NORMAL:
-		buf = "normal";
+		buf = (char*) "normal";
 		break;
 	case PANGO_STYLE_OBLIQUE:
-		buf = "oblique";
+		buf = (char*) "oblique";
 		break;
 	case PANGO_STYLE_ITALIC:
-		buf = "italic";
+		buf = (char*) "italic";
 		break;
 	}
 	if (buf)
@@ -606,25 +619,25 @@ bool gcpTheme::Save (xmlDocPtr xml)
 	buf = NULL;
 	switch (m_FontWeight) {
 	case PANGO_WEIGHT_ULTRALIGHT:
-		buf = "ultra-light";
+		buf = (char*) "ultra-light";
 		break;
 	case PANGO_WEIGHT_LIGHT:
-		buf = "light";
+		buf = (char*) "light";
 		break;
 	case PANGO_WEIGHT_NORMAL:
-		buf = "normal";
+		buf = (char*) "normal";
 		break;
 	case PANGO_WEIGHT_SEMIBOLD:
-		buf = "semi-bold";
+		buf = (char*) "semi-bold";
 		break;
 	case PANGO_WEIGHT_BOLD:
-		buf = "bold";
+		buf = (char*) "bold";
 		break;
 	case PANGO_WEIGHT_ULTRABOLD:
-		buf = "ultra-bold";
+		buf = (char*) "ultra-bold";
 		break;
 	case PANGO_WEIGHT_HEAVY:
-		buf = "heavy";
+		buf = (char*) "heavy";
 		break;
 	}
 	if (buf)
@@ -633,31 +646,31 @@ bool gcpTheme::Save (xmlDocPtr xml)
 	buf = NULL;
 	switch (m_FontStretch) {
 	case PANGO_STRETCH_ULTRA_CONDENSED:
-		buf = "ultra-condensed";
+		buf = (char*) "ultra-condensed";
 		break;
 	case PANGO_STRETCH_EXTRA_CONDENSED:
-		buf = "extra-condensed";
+		buf = (char*) "extra-condensed";
 		break;
 	case PANGO_STRETCH_CONDENSED:
-		buf = "condensed";
+		buf = (char*) "condensed";
 		break;
 	case PANGO_STRETCH_SEMI_CONDENSED:
-		buf = "semi-condensed";
+		buf = (char*) "semi-condensed";
 		break;
 	case PANGO_STRETCH_NORMAL:
-		buf = "normal";
+		buf = (char*) "normal";
 		break;
 	case PANGO_STRETCH_SEMI_EXPANDED:
-		buf = "semi-expanded";
+		buf = (char*) "semi-expanded";
 		break;
 	case PANGO_STRETCH_EXPANDED:
-		buf = "expanded";
+		buf = (char*) "expanded";
 		break;
 	case PANGO_STRETCH_EXTRA_EXPANDED:
-		buf = "extra-expanded";
+		buf = (char*) "extra-expanded";
 		break;
 	case PANGO_STRETCH_ULTRA_EXPANDED:
-		buf = "ultra-expanded";
+		buf = (char*) "ultra-expanded";
 		break;
 	}
 	if (buf)
@@ -669,13 +682,13 @@ bool gcpTheme::Save (xmlDocPtr xml)
 	buf = NULL;
 	switch (m_TextFontStyle) {
 	case PANGO_STYLE_NORMAL:
-		buf = "normal";
+		buf = (char*) "normal";
 		break;
 	case PANGO_STYLE_OBLIQUE:
-		buf = "oblique";
+		buf = (char*) "oblique";
 		break;
 	case PANGO_STYLE_ITALIC:
-		buf = "italic";
+		buf = (char*) "italic";
 		break;
 	}
 	if (buf)
@@ -683,25 +696,25 @@ bool gcpTheme::Save (xmlDocPtr xml)
 	buf = NULL;
 	switch (m_TextFontWeight) {
 	case PANGO_WEIGHT_ULTRALIGHT:
-		buf = "ultra-light";
+		buf = (char*) "ultra-light";
 		break;
 	case PANGO_WEIGHT_LIGHT:
-		buf = "light";
+		buf = (char*) "light";
 		break;
 	case PANGO_WEIGHT_NORMAL:
-		buf = "normal";
+		buf = (char*) "normal";
 		break;
 	case PANGO_WEIGHT_SEMIBOLD:
-		buf = "semi-bold";
+		buf = (char*) "semi-bold";
 		break;
 	case PANGO_WEIGHT_BOLD:
-		buf = "bold";
+		buf = (char*) "bold";
 		break;
 	case PANGO_WEIGHT_ULTRABOLD:
-		buf = "ultra-bold";
+		buf = (char*) "ultra-bold";
 		break;
 	case PANGO_WEIGHT_HEAVY:
-		buf = "heavy";
+		buf = (char*) "heavy";
 		break;
 	}
 	if (buf)
@@ -710,31 +723,31 @@ bool gcpTheme::Save (xmlDocPtr xml)
 	buf = NULL;
 	switch (m_TextFontStretch) {
 	case PANGO_STRETCH_ULTRA_CONDENSED:
-		buf = "ultra-condensed";
+		buf = (char*) "ultra-condensed";
 		break;
 	case PANGO_STRETCH_EXTRA_CONDENSED:
-		buf = "extra-condensed";
+		buf = (char*) "extra-condensed";
 		break;
 	case PANGO_STRETCH_CONDENSED:
-		buf = "condensed";
+		buf = (char*) "condensed";
 		break;
 	case PANGO_STRETCH_SEMI_CONDENSED:
-		buf = "semi-condensed";
+		buf = (char*) "semi-condensed";
 		break;
 	case PANGO_STRETCH_NORMAL:
-		buf = "normal";
+		buf = (char*) "normal";
 		break;
 	case PANGO_STRETCH_SEMI_EXPANDED:
-		buf = "semi-expanded";
+		buf = (char*) "semi-expanded";
 		break;
 	case PANGO_STRETCH_EXPANDED:
-		buf = "expanded";
+		buf = (char*) "expanded";
 		break;
 	case PANGO_STRETCH_EXTRA_EXPANDED:
-		buf = "extra-expanded";
+		buf = (char*) "extra-expanded";
 		break;
 	case PANGO_STRETCH_ULTRA_EXPANDED:
-		buf = "ultra-expanded";
+		buf = (char*) "ultra-expanded";
 		break;
 	}
 	if (buf)
@@ -973,8 +986,7 @@ void gcpTheme::RemoveClient (Object *client)
 	set <Object*>::iterator iter = m_Clients.find (client);
 	if (iter != m_Clients.end ())
 		m_Clients.erase (iter);
-	if (m_ThemeType == FILE_THEME_TYPE && m_Clients.size () == 0)
-	{
+	if (m_ThemeType == FILE_THEME_TYPE && m_Clients.size () == 0) {
 		ThemeManager.RemoveFileTheme (this);
 		delete this;
 	}
