@@ -4,7 +4,7 @@
  * GChemPaint cycles plugin
  * cycletool.cc 
  *
- * Copyright (C) 2001-2006 Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2001-2007 Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -28,20 +28,21 @@
 #include "lib/document.h"
 #include "lib/application.h"
 #include "lib/theme.h"
-#include <math.h>
+#include <glib/gi18n-lib.h>
+#include <cmath>
 #include <list>
 #include <vector>
 
 using namespace std;
 
 static char* ToolNames [] = {
-	"Cycle3",
-	"Cycle4",
-	"Cycle5",
-	"Cycle6",
-	"Cycle7",
-	"Cycle8",
-	"CycleN",
+	(char*) "Cycle3",
+	(char*) "Cycle4",
+	(char*) "Cycle5",
+	(char*) "Cycle6",
+	(char*) "Cycle7",
+	(char*) "Cycle8",
+	(char*) "CycleN",
 };
 
 gcpCycleTool::gcpCycleTool(gcpApplication *App, unsigned char size): gcpTool(App, ToolNames[size - 3])
@@ -552,7 +553,7 @@ void gcpCycleTool::OnRelease()
 	gcpDocument *pDoc = m_pView->GetDoc ();
 	gcpOperation *pOp = NULL;
 	gcpMolecule *pMol = NULL;
-	char const *MolId;
+	char const *MolId = NULL;
 	int i;
 	for (i = 0; i < m_size; i++)
 	{
@@ -766,7 +767,7 @@ void gcpCycleTool::SetLength (double length)
 
 GtkWidget *gcpCycleTool::GetPropertyPage ()
 {
-	GladeXML *xml = glade_xml_new (DATADIR"/gchempaint-unstable/ui/cycle.glade", "cycle", GETTEXT_PACKAGE);
+	GladeXML *xml = glade_xml_new (GLADEDIR"/cycle.glade", "cycle", GETTEXT_PACKAGE);
 	m_LengthBtn = GTK_SPIN_BUTTON (glade_xml_get_widget (xml, "bond-length"));
 	g_signal_connect (m_LengthBtn, "value-changed", G_CALLBACK (on_length_changed), this);
 	m_MergeBtn = GTK_TOGGLE_BUTTON (glade_xml_get_widget (xml, "merge"));
@@ -781,18 +782,6 @@ void gcpCycleTool::Activate ()
 	gtk_toggle_button_set_active (m_MergeBtn, MergeAtoms);
 }
 
-class gcpCNToolDlg: public Dialog
-{
-public:
-	gcpCNToolDlg(gcpApplication* App, unsigned char size = 9);
-	virtual ~gcpCNToolDlg();
-
-	virtual bool Apply();
-	
-private:
-	GtkSpinButton* m_button;
-};
-
 gcpNCycleTool::gcpNCycleTool(gcpApplication* App, unsigned char size): gcpCycleTool(App, 9)
 {
 	SetSize(size);
@@ -819,7 +808,7 @@ static void on_size_changed (GtkSpinButton *button, gcpNCycleTool *tool)
 
 GtkWidget *gcpNCycleTool::GetPropertyPage ()
 {
-	GladeXML *xml = glade_xml_new (DATADIR"/gchempaint-unstable/ui/cyclen.glade", "cycle", GETTEXT_PACKAGE);
+	GladeXML *xml = glade_xml_new (GLADEDIR"/cyclen.glade", "cycle", GETTEXT_PACKAGE);
 	m_LengthBtn = GTK_SPIN_BUTTON (glade_xml_get_widget (xml, "bond-length"));
 	g_signal_connect (m_LengthBtn, "value-changed", G_CALLBACK (on_length_changed), NULL);
 	m_MergeBtn = GTK_TOGGLE_BUTTON (glade_xml_get_widget (xml, "merge"));
@@ -828,35 +817,3 @@ GtkWidget *gcpNCycleTool::GetPropertyPage ()
 	g_signal_connect (m_SizeBtn, "value-changed", G_CALLBACK (on_size_changed), this);
 	return glade_xml_get_widget (xml, "cycle");
 }
-
-void gcpNCycleTool::SetOptions ()
-{
-	gcpCNToolDlg* dlg = (gcpCNToolDlg*) m_pApp->GetDialog ("CycleN");
-	if (!dlg)
-	{
-		dlg = new gcpCNToolDlg (m_pApp, GetSize ());
-	}
-	else gdk_window_raise (GTK_WIDGET (dlg->GetWindow ())->window); 
-}
-
-gcpCNToolDlg::gcpCNToolDlg(gcpApplication* App, unsigned char size): Dialog(App, DATADIR"/gchempaint-unstable/ui/cyclentool.glade", "cyclentool")
-{
-	m_button = GTK_SPIN_BUTTON(glade_xml_get_widget(xml, "sizebtn"));
-	gtk_spin_button_set_value(m_button, size);
-	App->SetDialog("CycleN", this);
-	gtk_widget_show(GTK_WIDGET(dialog));
-}
-
-gcpCNToolDlg::~gcpCNToolDlg ()
-{
-	reinterpret_cast<gcpApplication*> (m_App)->SetDialog ("CycleN", NULL);
-}
-
-bool gcpCNToolDlg::Apply ()
-{
-	gcpNCycleTool* tool = (gcpNCycleTool*)
-			reinterpret_cast<gcpApplication*> (m_App)->GetTool ("CycleN");
-	if (tool)
-		tool->SetSize ((unsigned char) gtk_spin_button_get_value_as_int (m_button));
-	return true;
-}
