@@ -762,7 +762,7 @@ static const guint16 font_sizes[] = {
 
 GtkWidget *gcpTextTool::GetPropertyPage ()
 {
-	GladeXML *xml = glade_xml_new (DATADIR"/gchempaint/ui/fontsel.glade", "fontsel", GETTEXT_PACKAGE);
+	GladeXML *xml = glade_xml_new (GLADEDIR"/fontsel.glade", "fontsel", GETTEXT_PACKAGE);
 	PangoFontFamily **families;
 	int i, nb;
 	gcpTheme *pTheme = m_pApp->GetActiveDocument ()->GetTheme ();
